==> 0.0.3.tar.gz: lib/API/PIA_API_Icon_Count.dart <==
import 'package:dio/src/dio_error.dart';
import 'package:flutter/material.dart';
import 'package:pia_framework/API/PIA_API_Background.dart';
import 'package:pia_framework/API/PIA_API_Widget.dart';
import 'package:pia_framework/Variable/PIA_Global.dart';
import 'package:pia_framework/Lang/PIA_Lang.dart';

class PIA_API_Icon_Count_Controller
{   PIA_API_Icon_Count_State state;
    void Update()
    {  state.update(); }
}


class PIA_API_Icon_Count extends StatefulWidget
{  String url;
   Map<String,String> post = Map<String,String>();
   Widget child;
   PIA_API_Icon_Count_Controller controller;
   double size = 20;
   PIA_API_Icon_Count({Key key, this.url,this.post,this.controller,this.child}) : super(key: key);

   @override
   State<StatefulWidget> createState() {
     // TODO: implement createState
     print("Create State");

     var state = PIA_API_Icon_Count_State();
     controller.state = state;
     return state;
  }
}


class PIA_API_Icon_Count_State  extends  State<PIA_API_Icon_Count> implements PIA_API_CallBack {

  int count = 10;

  void update()
  {  PIA_API_Background.Post(widget.url, widget.post, this); }


  @override
  void dispose() {
    super.dispose();
    PIA_API_Background.Stop();
  }


  @override
  Widget build(BuildContext context) {
      print("Widget size ${widget.size}");

      return Stack(children: <Widget>[
        widget.child,
        (count>0)?
        Container(
          margin: EdgeInsets.only(left: 25,top:5),
          width:widget.size,
          height: widget.size,
          decoration: new BoxDecoration(
            shape: BoxShape.circle,
            color: Colors.deepOrange,
          ),
          //color: Colors.deepOrange,
          child:
            Center(child:Text("${count}",style:TextStyle(color:Colors.white,fontSize: 13))),
          //child:Text("${count}",style:TextStyle(fontSize: widget.size * 0.7,color: Colors.white)),
        ):
        Container(width: 0, height: 0,),
      ],);

  }

  @override
  void API_Error(DioErrorType error) {
    // TODO: implement API_Error
  }

  @override
  void API_Success(Map<String, dynamic> json, List j) {
    count =  int.tryParse(json["count"].toString());
    setState(() {
    });
  }

  @override
  void API_Upload_prodcess(int upload, int total) {
    // TODO: implement API_Upload_prodcess
  }

}

==> 0.0.5.tar.gz: lib/API/PIA_API_Icon_Count.dart <==
import 'package:dio/src/dio_error.dart';
import 'package:flutter/material.dart';
import 'package:pia_framework/API/PIA_API_Background.dart';
import 'package:pia_framework/API/PIA_API_Widget.dart';
import 'package:pia_framework/Variable/PIA_Global.dart';
import 'package:pia_framework/Lang/PIA_Lang.dart';


class PIA_API_Icon_Count extends StatefulWidget
{  String url;
   Map<String,String> post = Map<String,String>();
   Widget icon;
   double size = 20;
   var onpress;

   PIA_API_Icon_Count({Key key, this.url,this.post,this.onpress,this.icon}) : super(key: key);

   @override
   State<StatefulWidget> createState() {
     // TODO: implement createState
     print("Create PIA_Icon State");

     return PIA_API_Icon_Count_State();
   }


}


class PIA_API_Icon_Count_State  extends  State<PIA_API_Icon_Count> implements PIA_API_CallBack {

  int count = 0;

  void update()
  {  PIA_API_Background.Post(widget.url, widget.post, this); }


  @override
  void dispose() {
    super.dispose();
    PIA_API_Background.Stop();
  }


  @override
  void didUpdateWidget(Widget oldWidget) {
    update();
    print("Icon Count didUpdateWidget");
  }

  @override
  void didChangeDependencies() {
    update();
    print("Icon Count didChangeDependencies");
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    print(" Icon Count didChangeDependencie:" + state.toString());
  }


  @override
  Widget build(BuildContext context) {
      print("PIA_Icon Build  ${widget.size}");

      return GestureDetector(
       onTap: widget.onpress,
       child:Stack(children: <Widget>[
        widget.icon,
        (count>0)?
        Container(
          margin: EdgeInsets.only(left: widget.size/2 + 5 ,top:0),
          width:widget.size,
          height: widget.size,
          decoration: new BoxDecoration(
            shape: BoxShape.circle,
            color: Colors.deepOrange,
          ),
          //color: Colors.deepOrange,
          child:
            Center(child:Text("${count}",style:TextStyle(color:Colors.white,fontSize: 13))),
        ):
        Container(width: 0, height: 0,),
      ],));

  }

  @override
  void API_Error(DioErrorType error) {
    // TODO: implement API_Error
  }

  @override
  void API_Success(Map<String, dynamic> json, List j) {
    count =  int.tryParse(json["count"].toString());
    setState(() {
      print("api success");
    });
  }

  @override
  void API_Upload_prodcess(int upload, int total) {
    // TODO: implement API_Upload_prodcess
  }

}
